@@ -8,8 +8,8 @@ Created on Wed Oct 31 16:23:13 2018
 import os
 
 __author__ = "Sam Schott"
-__version__ = "1.4.2"
-__url__ = "https://github.com/SamSchott/maestral"
+__version__ = "1.4.3"
+__url__ = "https://samschott.github.io/maestral"
 
 # add '~/.local/share' to XDG_DATA_DIRS
 # this is needed to find icons installed for the current user only
