@@ -34,8 +34,10 @@ from maestral.daemon import (
     Start,
     CommunicationError,
 )
+from maestral.errors import KeyringAccessError
 
 # local imports
+from maestral_qt import __url__
 from maestral_qt.setup_dialog import SetupDialog
 from maestral_qt.relink_dialog import RelinkDialog
 from maestral_qt.settings_window import SettingsWindow
@@ -179,7 +181,13 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
 
         self.mdbx = self.get_or_start_maestral_daemon()
 
-        if self.mdbx.pending_link or self.mdbx.pending_dropbox_folder:
+        try:
+            pending_link = self.mdbx.pending_link
+        except KeyringAccessError:
+            self.update_error()
+            return
+
+        if pending_link or self.mdbx.pending_dropbox_folder:
             self.loading_done = SetupDialog.configureMaestral(self.mdbx)
         else:
             self.loading_done = True
@@ -389,7 +397,7 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
     @QtCore.pyqtSlot()
     def on_help_clicked(self):
         """Open the Dropbox help website."""
-        click.launch("https://dropbox.com/help")
+        click.launch(f"{__url__}/docs")
 
     @QtCore.pyqtSlot()
     def on_start_stop_clicked(self):
@@ -508,9 +516,12 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
             self.mdbx.clear_fatal_errors()
 
         self.setIcon(ERROR)
-        self.pauseAction.setText(self.RESUME_TEXT)
-        self.pauseAction.setEnabled(False)
-        self.statusAction.setText(self.mdbx.status)
+
+        if self.pauseAction:
+            self.pauseAction.setText(self.RESUME_TEXT)
+
+        if self.statusAction:
+            self.statusAction.setText(self.mdbx.status)
 
         err = errs[-1]
 
